@@ -7,6 +7,7 @@ from pydantic import BaseModel
 
 from blackcap.schemas.api.common import ResponseSchema
 from blackcap.schemas.user import User
+from pydantic.types import UUID4
 
 
 @unique
@@ -14,7 +15,7 @@ class UserQueryType(Enum):
     """User Query type enum."""
 
     GET_ALL_USERS = "get_all_users"
-    GET_USERS_BY_ID = "get_user_by_id"
+    GET_USER_BY_ID = "get_user_by_id"
     GET_USERS_BY_EMAIL = "get_users_by_email"
     GET_USERS_BY_ORGANISATION = "get_users_by_organisation"
 
@@ -23,7 +24,7 @@ class UserGetQueryParams(BaseModel):
     """User GET request query params schema."""
 
     query_type: UserQueryType
-    user_id: Optional[str]
+    user_id: Optional[UUID4]
     email: Optional[str]
     organisation: Optional[str]
 
